@@ -9,7 +9,7 @@ mod loader;
 mod op;
 
 pub use {
-    chunk::{chunk_to_string, chunk_to_string_annotated, Chunk, DebugInfo},
+    chunk::{Chunk, DebugInfo},
     compiler::{Compiler, CompilerError, CompilerSettings},
     instruction_reader::{FunctionFlags, Instruction, InstructionReader, TypeId},
     loader::{Loader, LoaderError},
